==> zzyj-outputvalcount-api-3.0.0-20240117.101437-286-sources.jar: com/ejianc/business/outputvalcount/vo/NodeAnalysisReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * NodeAnalysisReportVO
 *
 * @author generator
 *
 */
public class NodeAnalysisReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long aid; // 主键ID
    private Long pid; //
    private String pname; //
    private Long orgid; //
    private String orgname; //
    private String porgname; //
    private String mbname; //
    private String assessname; //
    private String memo; //

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date assesstime; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date createtime; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date reportdate; //

    private String analysisType; //
    private String analysisNum; //
    private BigDecimal srsjrate; //
    private Long typeid; //
    private String typename; //


    public Long getAid() {
        return aid;
    }

    public void setAid(Long aid) {
        this.aid = aid;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getPname() {
        return pname;
    }

    public void setPname(String pname) {
        this.pname = pname;
    }

    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }

    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }

    public String getPorgname() {
        return porgname;
    }

    public void setPorgname(String porgname) {
        this.porgname = porgname;
    }

    public String getMbname() {
        return mbname;
    }

    public void setMbname(String mbname) {
        this.mbname = mbname;
    }

    public String getAssessname() {
        return assessname;
    }

    public void setAssessname(String assessname) {
        this.assessname = assessname;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Date getAssesstime() {
        return assesstime;
    }

    public void setAssesstime(Date assesstime) {
        this.assesstime = assesstime;
    }

    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    public Date getReportdate() {
        return reportdate;
    }

    public void setReportdate(Date reportdate) {
        this.reportdate = reportdate;
    }

    public String getAnalysisType() {
        return analysisType;
    }

    public void setAnalysisType(String analysisType) {
        this.analysisType = analysisType;
    }

    public String getAnalysisNum() {
        return analysisNum;
    }

    public void setAnalysisNum(String analysisNum) {
        this.analysisNum = analysisNum;
    }

    public BigDecimal getSrsjrate() {
        return srsjrate;
    }

    public void setSrsjrate(BigDecimal srsjrate) {
        this.srsjrate = srsjrate;
    }

    public Long getTypeid() {
        return typeid;
    }

    public void setTypeid(Long typeid) {
        this.typeid = typeid;
    }

    public String getTypename() {
        return typename;
    }

    public void setTypename(String typename) {
        this.typename = typename;
    }
}

==> zzyj-outputvalcount-api-3.0.0-20250115.075045-354-sources.jar: com/ejianc/business/outputvalcount/vo/NodeAnalysisReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * NodeAnalysisReportVO
 *
 * @author generator
 *
 */
public class NodeAnalysisReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long aid; // 主键ID
    private Long pid; //
    private String pname; //
    private Long orgid; //
    private String orgname; //
    private String porgname; //
    private String mbname; //
    private String assessname; //
    private String memo; //

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date assesstime; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date createtime; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date reportdate; //

    private String analysisType; //
    private String analysisNum; //
    private BigDecimal srsjrate; //
    private Long typeid; //
    private String typename; //
    private Long dutyid; //


    public Long getDutyid() {
        return dutyid;
    }

    public void setDutyid(Long dutyid) {
        this.dutyid = dutyid;
    }

    public Long getAid() {
        return aid;
    }

    public void setAid(Long aid) {
        this.aid = aid;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getPname() {
        return pname;
    }

    public void setPname(String pname) {
        this.pname = pname;
    }

    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }

    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }

    public String getPorgname() {
        return porgname;
    }

    public void setPorgname(String porgname) {
        this.porgname = porgname;
    }

    public String getMbname() {
        return mbname;
    }

    public void setMbname(String mbname) {
        this.mbname = mbname;
    }

    public String getAssessname() {
        return assessname;
    }

    public void setAssessname(String assessname) {
        this.assessname = assessname;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Date getAssesstime() {
        return assesstime;
    }

    public void setAssesstime(Date assesstime) {
        this.assesstime = assesstime;
    }

    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    public Date getReportdate() {
        return reportdate;
    }

    public void setReportdate(Date reportdate) {
        this.reportdate = reportdate;
    }

    public String getAnalysisType() {
        return analysisType;
    }

    public void setAnalysisType(String analysisType) {
        this.analysisType = analysisType;
    }

    public String getAnalysisNum() {
        return analysisNum;
    }

    public void setAnalysisNum(String analysisNum) {
        this.analysisNum = analysisNum;
    }

    public BigDecimal getSrsjrate() {
        return srsjrate;
    }

    public void setSrsjrate(BigDecimal srsjrate) {
        this.srsjrate = srsjrate;
    }

    public Long getTypeid() {
        return typeid;
    }

    public void setTypeid(Long typeid) {
        this.typeid = typeid;
    }

    public String getTypename() {
        return typename;
    }

    public void setTypename(String typename) {
        this.typename = typename;
    }
}
